/* this a macro to quickly calculate polarity in the AC for a one-channel image. It will return 
 *  three lines of results.
 * Polarity on each line is AC first, then IM
 * Line 1 is the apical domain of the AC
 * Line 2 is the invasive membrane
 * Line 3 is a second run of the invasive membrane (if required - usually just for the protrusion)
 * Line 4 is a third run of the invasive membrane (if required)
 * IMPORTANT - Change the code in line 14 to match proper pixel size for your image:
 * IMPORTANT - Ensure freehand lines are 5-pixels wide. The code on line 41 does not work for all versions of Fiji
 */
image=getTitle;
n=nSlices;
run("Set Measurements...", "area mean integrated redirect=None decimal=3");
run("Properties...", "channels=1 slices=n frames=1 unit=µm pixel_width=.15 pixel_height=.15 voxel_depth=0.5000000");
roiManager("Reset");
run("Subtract Background...", "rolling=100 stack");
//calculate polarity of a single slice of the AC
waitForUser("select the center-most slice of the AC");
run("Duplicate...", "title=slice");
selectWindow("slice");
//run("Brightness/Contrast...");
resetMinAndMax();
selectWindow("slice");
setTool("point");
waitForUser("mark the AC");
run("To Selection");
run("Out [-]");
run("Out [-]");
run("Out [-]");
run("Out [-]");
run("Out [-]");
setTool("freeline");
setLineWidth(5);
waitForUser("draw a line along the apical membrane.");
run("Measure");
selectWindow(image);
waitForUser("select the center-most slice of the protrusion");
run("Duplicate...", "title=protrusion");
//run("Brightness/Contrast...");
resetMinAndMax();
selectWindow("protrusion");
setTool("point");
waitForUser("mark the AC");
run("To Selection");
run("Out [-]");
run("Out [-]");
run("Out [-]");
run("Out [-]");
run("Out [-]");
setTool("freeline");
waitForUser("draw a line along the invasive membrane.");
run("Measure");
roiManager("Add");
roiManager("Show All");
//run("Select None");
waitForUser("draw another invasive membrane line if needed; if not, just click OK");
run("Measure");
roiManager("Add");
roiManager("Show All");
waitForUser("draw a third invasive membrane line if needed; if not, just click OK");
run("Measure");
run("Close All");