/* FLIP Analsys and Heatmap Generator
 * ImageJ/Fiji code written by Kaleb M. Naegeli, Duke Unviersity
 * IMPORTANT: this code generates comparisons of cell regions and makes heatmaps for these regions
 * for 1 cycle and 3 cycles of photobleaching. 3-cycle data were used in this publication.
 * IMPORTANT: This code only works for .lsm files from a Zeiss imaging system. Image files from other
 * systems require a code change in line 10. 
 * IMPORTANT: You must specify your own file paths in 
 * lines 19, 37, 46, 51, 60, 66, 75, and 80.
 */
image=getTitle;
//print(image);
tiff_name=replace(image,".lsm","");

//this makes the files that are used for later comparisons
run("Z Project...", "projection=[Sum Slices] all");
run("Slice Keeper", "first=1 last=4 increment=1");
run("Subtract Background...", "rolling=50 stack");
run("StackReg", "transformation=[Rigid Body]");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-projection");
rename("Sum.lsm");
//run("Brightness/Contrast...");
resetMinAndMax();
selectWindow("Sum.lsm");
run("Duplicate...", "title=1.lsm duplicate range=1-1");
selectWindow("Sum.lsm");
run("Duplicate...", "title=2.lsm duplicate range=2-2");
selectWindow("Sum.lsm");
run("Duplicate...", "title=4.lsm duplicate range=4-4");
//cycle 1 comparisons
imageCalculator("Subtract create 32-bit", "1.lsm","2.lsm");
rename("1sub.lsm");
imageCalculator("Divide create 32-bit", "1sub.lsm","1.lsm");
//run("Brightness/Contrast...");
setMinAndMax(0.000000000, 0.500000000);
rename("1 cycle.lsm");
run("Fire");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-1wbg");
run("Duplicate...", "title=1cyctemp.tif");
//cycle1 mask
selectWindow("1.lsm");
run("Duplicate...", "title=1-1.lsm");
//run("Threshold...");
setAutoThreshold("Default dark");
run("Make Binary");
run("Fill Holes");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-MASK");
rename("1-1.lsm");
imageCalculator("AND create", "1-1.lsm","1cyctemp.tif");
rename("1 cycle masked.lsm");
run("Fire");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-1mask");
//3 cycle comparison
imageCalculator("Subtract create 32-bit", "1.lsm","4.lsm");
rename("3sub.lsm");
imageCalculator("Divide create 32-bit", "3sub.lsm","1.lsm");
//run("Brightness/Contrast...");
setMinAndMax(0.000000000, 0.500000000);
rename("3 cycle.lsm");
run("Fire");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-3wbg");
run("Duplicate...", "title=3cyctemp.tif");
//3 cycle mask
imageCalculator("AND create", "1-1.lsm","3cyctemp.tif");
rename("3 cycle masked.lsm");
run("Fire");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-3mask");
//smoothed comparisons images
selectWindow("1.lsm");
run("Duplicate...", "title=1add.lsm");
run("Add...", "value=100");
imageCalculator("Divide create 32-bit", "1sub.lsm","1add.lsm");
setMinAndMax(0.000000000, 0.500000000);
run("Fire");
run("Smooth");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-1smooth");
imageCalculator("Divide create 32-bit", "3sub.lsm","1add.lsm");
setMinAndMax(0.000000000, 0.500000000);
run("Fire");
run("Smooth");
saveAs("Tiff", "C:\\Users\\Kaleb\\Documents\\0 Sherwood Lab\\FLIP\\780 Upright\\Macro Heatmaps\\"+tiff_name+"-3smooth");
run("Close All");